==> ublock-origin_1.19.0+dfsg.orig.tar.xz: ublock-origin-1.19.0+dfsg/src/js/asset-viewer.js <==
/*******************************************************************************

    uBlock Origin - a browser extension to block requests.
    Copyright (C) 2014-present Raymond Hill

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.

    Home: https://github.com/gorhill/uBlock
*/

/* global CodeMirror, uBlockDashboard */

'use strict';

/******************************************************************************/

(function() {

    let params = new URL(document.location).searchParams;
    let assetKey = params.get('url');
    if ( assetKey === null ) { return; }

    vAPI.messaging.send(
        'default',
        {
            what : 'getAssetContent',
            url: assetKey
        },
        details => {
            cmEditor.setValue(details && details.content || '');
        }
    );

    let cmEditor = new CodeMirror(
        document.getElementById('content'),
        {
            autofocus: true,
            lineNumbers: true,
            lineWrapping: true,
            readOnly: true,
            styleActiveLine: true,
        }
    );

    uBlockDashboard.patchCodeMirrorEditor(cmEditor);
})();

==> ublock-origin_1.22.2+dfsg.orig.tar.xz: ublock-origin-1.22.2+dfsg/src/js/asset-viewer.js <==
/*******************************************************************************

    uBlock Origin - a browser extension to block requests.
    Copyright (C) 2014-present Raymond Hill

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see {http://www.gnu.org/licenses/}.

    Home: https://github.com/gorhill/uBlock
*/

/* global CodeMirror, uBlockDashboard */

'use strict';

/******************************************************************************/

(( ) => {
    const params = new URL(document.location).searchParams;
    const assetKey = params.get('url');
    if ( assetKey === null ) { return; }

    vAPI.messaging.send(
        'default',
        {
            what : 'getAssetContent',
            url: assetKey,
        },
        details => {
            cmEditor.setValue(details && details.content || '');
            if ( details.sourceURL ) {
                const a = document.querySelector('.cm-search-widget .sourceURL');
                a.setAttribute('href', details.sourceURL);
                a.setAttribute('title', details.sourceURL);
            }
        }
    );

    const cmEditor = new CodeMirror(
        document.getElementById('content'),
        {
            autofocus: true,
            lineNumbers: true,
            lineWrapping: true,
            readOnly: true,
            styleActiveLine: true,
        }
    );

    uBlockDashboard.patchCodeMirrorEditor(cmEditor);
})();
